@@ -661,9 +661,11 @@ class FacileToolkit2:
 
     @keyword
     def screenshot_on_failure(self):
-        self._log_field_values()
-        BuiltIn().run_keyword_if_test_failed("capture_page_screenshot", "EMBED")
-        self.sl.log_location()
+        self.set_selenium_library()
+        if self.sl._drivers.current:
+            self._log_field_values()
+            BuiltIn().run_keyword_if_test_failed("capture_page_screenshot", "EMBED")
+            self.sl.log_location()
 
     def _log_field_values(self):
         try:
@@ -677,10 +679,11 @@ class FacileToolkit2:
     @keyword
     def teardown_with_screenshot(self):
         self.set_selenium_library()
-        self._log_field_values()
-        BuiltIn().run_keyword_if_test_failed("capture_page_screenshot", "EMBED")
-        self.sl.log_location()
-        self.sl.close_all_browsers()
+        if self.sl._drivers.current:
+            self._log_field_values()
+            BuiltIn().run_keyword_if_test_failed("capture_page_screenshot", "EMBED")
+            self.sl.log_location()
+            self.sl.close_all_browsers()
 
     def i_see_elements_label(self, *locators):
         self.set_selenium_library()
@@ -690,9 +693,9 @@ class FacileToolkit2:
                                                                                                                 "id"))
 
     @keyword
-    def close_symfony_toolbar(self):
+    def close_symfony_toolbar(self, timeout=None):
         self.set_selenium_library()
-        if BuiltIn().run_keyword_and_return_status("wait_until_element_is_visible", "css:body > .sf-toolbar"):
+        if BuiltIn().run_keyword_and_return_status("wait_until_element_is_visible", "css:body > .sf-toolbar", timeout):
             self.sl.execute_javascript("document.querySelector('body > .sf-toolbar').style='display:none'")
 
     @keyword
